@@ -18,6 +18,7 @@
 
 import itertools
 import unittest
+import sys
 
 from proclets.mission import Control
 from proclets.mission import Recovery
@@ -50,6 +51,9 @@ class MissionTests(unittest.TestCase):
                     n += 1
             except Termination:
                 break
+            except Exception as e:
+                #print(n, m, p, file=sys.stderr)
+                raise
 
     def test_flow(self):
         for n, p, m in self.run_to_terminate(self.procs):
